==> nocc-1.8.3.tbz: www/nocc/lang/sr-ec.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: sr-ec.php 2199 2010-06-03 23:40:34Z siebrand $
 */

/** Serbian Cyrillic ekavian (Српски (ћирилица))
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Charmed94
 * @author Михајло Анђелковић
 */

$default_date_format = '%d-%m-%y';
$no_locale_date_format = '%d-%m-%y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Поље за пријаву је празно';
$err_passwd_empty = 'Поље за лозинку је празно';
$alt_delete = 'Обриши изабране поруке';
$alt_delete_one = 'Обриши поруку';
$alt_new_msg = 'Нове поруке';
$alt_reply = 'Одговори аутору';
$alt_reply_all = 'Одговори све';
$alt_forward = 'Проследи';
$alt_next = 'Следеће';
$alt_prev = 'Претходно';
$title_next_page = 'Следећа страна';
$title_prev_page = 'Претходна страна';
$title_next_msg = 'Следећа порука';
$title_prev_msg = 'Претходна порука';
$html_theme_label = 'Тема:';
$html_welcome = 'Добро дошли у %1$s';
$html_login = 'Пријава';
$html_user_label = 'Корисничко име:';
$html_passwd_label = 'Лозинка:';
$html_submit = 'Пошаљи';
$html_help = 'Помоћ';
$html_server_label = 'Сервер:';
$html_wrong = 'Корисничко име или лозинка је неисправна';
$html_retry = 'Покушај поново';
$html_remember = 'Запамти поставке';
$html_lang_label = 'Језик:';
$html_msgperpage_label = 'Порука по страни:';
$html_preferences = 'Поставке';
$html_full_name_label = 'Пуно име:';
$html_email_address_label = 'Е-адреса:';
$html_ccself = 'Cc себи';
$html_hide_addresses = 'Сакриј адресе';
$html_outlook_quoting = 'Outlook стил цитирања';
$html_reply_to = 'Одговори';
$html_use_signature = 'Користи потпис';
$html_signature = 'Потпис';
$html_signature_label = 'Потпис:';
$html_reply_leadin_label = 'Одговори водећи:';
$html_prefs_updated = 'Поставке су ажуриране';
$html_manage_folders_link = 'Управљање IMAP фасциклама';
$html_manage_filters_link = 'Управљање филтерима е-поште';
$html_use_graphical_smilies = 'Користи емотиконе';
$html_sent_folder_label = 'Умножи послате е-поруке у одређену фасциклу:';
$html_trash_folder_label = 'Премести обрисане е-поруке у одређену фасциклу:';
$html_colored_quotes = 'Обојени цитати';
$html_display_struct = 'Прикажи састављен текст';
$html_send_html_mail = 'Пошаљи е-поруку у HTML формату';
$html_folders = 'Фасцикле';
$html_folders_create_failed = 'Фасцикла се не може направити!';
$html_folders_sub_failed = 'Не можете се претплатити на фасциклу!';
$html_folders_unsub_failed = 'Не можете се одјавити из фасцикле!';
$html_folders_rename_failed = 'Фасцикла се не може преименовати!';
$html_folders_updated = 'Фасцикла је ажурирана';
$html_folder_subscribe = 'Претплати се на';
$html_folder_rename = 'Преименуј';
$html_folder_create = 'Направи нову фасциклу названу';
$html_folder_remove = 'Одјави се из';
$html_folder_delete = 'Обриши';
$html_folder_to = 'у';
$html_filter_remove = 'Обриши';
$html_filter_body = 'Тело поруке';
$html_filter_subject = 'Наслов поруке';
$html_filter_to = 'У поље';
$html_filter_cc = 'Cc поље';
$html_filter_from = 'Из поља';
$html_filter_change_tip = 'Да промените филтер, једноставно га замените.';
$html_reapply_filters = 'Поново примени све филтере';
$html_filter_contains = 'садржи';
$html_filter_name = 'Назив филтера';
$html_filter_action = 'Радња филтера';
$html_filter_moveto = 'Премести у';
$html_select_one = '--Изаберите један--';
$html_and = 'и';
$html_new_msg_in = 'Нове поруке у';
$html_or = 'или';
$html_move = 'Премести';
$html_copy = 'Умножи';
$html_messages_to = 'изабране поруке у';
$html_gotopage = 'Пређи на страну';
$html_gotofolder = 'Пређи на фасциклу';
$html_other_folders = 'Списак фасцикли';
$html_page = 'Страна';
$html_of = 'од';
$html_view_header = 'Прикажи заглавље';
$html_remove_header = 'Сакриј заглавље';
$html_inbox = 'Сандуче';
$html_new_msg = 'Напиши';
$html_reply = 'Одговори';
$html_reply_short = 'Одг:';
$html_reply_all = 'Одговори све';
$html_forward = 'Проследи';
$html_forward_short = 'Просл.:';
$html_forward_info = 'Прослеђена порука биће послата као прилог ове поруке.';
$html_delete = 'Обриши';
$html_new = 'Ново';
$html_mark = 'Обриши';
$html_att_label = 'Прилог:';
$html_atts_label = 'Прилози:';
$html_unknown = '[непознато]';
$html_attach = 'Приложи';
$html_attach_forget = 'Морате да приложите своје датотеке пре него што пошаљете поруку!';
$html_attach_delete = 'Уклони изабрано';
$html_attach_none = 'Морате да изаберете датотеку за прилог!';
$html_sort_by = 'Сврстај по';
$html_sort = 'Сврстај';
$html_from = 'Од';
$html_from_label = 'Од:';
$html_subject = 'Наслов';
$html_subject_label = 'Наслов:';
$html_date = 'Датум';
$html_date_label = 'Датум:';
$html_sent_label = 'Послато:';
$html_wrote = 'написано';
$html_size = 'Величина';
$html_totalsize = 'Укупна величина';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'бајтова';
$html_filename = 'Назив датотеке';
$html_to = 'За';
$html_to_label = 'За:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Без наслова';
$html_send = 'Пошаљи';
$html_cancel = 'Откажи';
$html_no_mail = 'Нема поруке.';
$html_logout = 'Одјави се';
$html_msg = 'Порука';
$html_msgs = 'Поруке';
$html_configuration = 'Овај сервер није исправно подешен!';
$html_priority = 'Приоритет';
$html_priority_label = 'Приоритет:';
$html_lowest = 'Најмањи';
$html_low = 'Мали';
$html_normal = 'Нормалан';
$html_high = 'Висок';
$html_highest = 'Највиши';
$html_flagged = 'Означено';
$html_spam = 'Непожељне поруке';
$html_spam_warning = 'Овај порука је означена као непожељна.';
$html_receipt = 'Затражи повратну потврду';
$html_select = 'Изабери';
$html_select_all = 'Обрни изабрано';
$html_select_contacts = 'Изабери контакте';
$html_loading_image = 'Учитавање слике';
$html_send_confirmed = 'Ваша е-адреса је прихваћена за доставу';
$html_no_sendaction = 'Нема одређене радње. Пробајте да омогућите јаваскрипту.';
$html_error_occurred = 'Дошло је до грешке';
$html_prefs_file_error = 'Отварање датотеке подешавања за писање није успело.';
$html_wrap = 'Број знакова за умотавање одлазних порука:';
$html_wrap_none = 'Без умотавања';
$html_usenet_separator = 'Раздвајач („-- \n“) пре потписа';
$html_mark_as = 'Означи као';
$html_read = 'прочитано';
$html_unread = 'непрочитано';
$html_encoding_label = 'Кодни распоред:';
$html_add = 'Додај';
$html_contacts = '%1$s контакти';
$html_modify = 'Измени';
$html_back = 'Назад';
$html_contact_add = 'Додај нови контакт';
$html_contact_mod = 'Измени контакт';
$html_contact_first = 'Име';
$html_contact_last = 'Презиме';
$html_contact_nick = 'Надимак';
$html_contact_mail = 'Е-пошта';
$html_contact_list = 'Контактни списак од %1$s';
$html_contact_del = 'из контактног списка';
$html_contact_count = '%1$d контакти';
$html_contact_err1 = 'Максималан број контаката је "%1$d"';
$html_contact_err2 = 'Не можете да додате нови контакт';
$html_contact_err3 = 'Немате овлашћења за контактни списак';
$html_contact_none = 'Контакти нису пронађени.';
$html_del_msg = 'Да ли желите да обришете изабране поруке?';
$html_down_mail = 'Преузми';
$original_msg = '-- Оригинална порука --';
$to_empty = 'Поље „За“ не може остати празно!';
$html_images_warning = 'Ради Ваше безбедности, слике нису приказане.';
$html_images_display = 'Прикажи слике';
$html_smtp_error_no_conn = 'Отварање SMTP везе није успело';
$html_smtp_error_unexpected = 'Неочекивани  SMTP одговор:';
$lang_could_not_connect = 'Повезивање на сервер није успело';
$lang_invalid_msg_num = 'Лош број поруке';
$html_file_upload_attack = 'Могући напад у току слања датотеке';
$html_invalid_email_address = 'Неисправна е-адреса';
$html_invalid_msg_per_page = 'Неисправан број порука по страни';
$html_invalid_wrap_msg = 'Неисправна ширина умотавања поруке';
$html_seperate_msg_win = 'Поруке у одвојеним прозорима';
$html_err_file_contacts = 'Отварање датотеке контакта за писање није успело.';
$html_session_file_error = 'Отварање датотеке сесије за писање није успело.';
$html_login_not_allowed = 'Пријава није дозвољена за везу.';
$lang_err_send_delay = 'Морате сачекати између две е-поруке (%1$d секунди)';
$html_search = 'Претрага';

==> nocc-1.9.1.tbz: www/nocc/lang/sr-ec.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: sr-ec.php 2400 2011-02-24 10:59:24Z siebrand $
 */
/** Serbian Cyrillic ekavian (‪Српски (ћирилица)‬)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Charmed94
 * @author Rancher
 * @author Михајло Анђелковић
 */

$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Поље за корисничко име је празно';
$err_passwd_empty = 'Поље за лозинку је празно';
$alt_delete = 'Обриши изабране поруке';
$alt_delete_one = 'Обриши поруку';
$alt_new_msg = 'Нове поруке';
$alt_reply = 'Одговори пошиљаоцу';
$alt_reply_all = 'Одговори свима';
$alt_forward = 'Проследи';
$alt_next = 'Следеће';
$alt_prev = 'Претходно';
$title_next_page = 'Следећа страница';
$title_prev_page = 'Претходна страница';
$title_next_msg = 'Следећа порука';
$title_prev_msg = 'Претходна порука';
$html_theme_label = 'Тема:';
$html_welcome = 'Добро дошли у %1$s';
$html_login = 'Пријави ме';
$html_user_label = 'Корисничко име:';
$html_passwd_label = 'Лозинка:';
$html_submit = 'Пошаљи';
$html_help = 'Помоћ';
$html_server_label = 'Сервер:';
$html_wrong = 'Корисничко име или лозинка су неисправни';
$html_retry = 'Покушај поново';
$html_remember = 'Сачувај поставке';
$html_lang_label = 'Језик:';
$html_msgperpage_label = 'Порука по страници:';
$html_preferences = 'Поставке';
$html_full_name_label = 'Пуно име:';
$html_email_address_label = 'Е-адреса:';
$html_bccself = 'Bcc себи';
$html_hide_addresses = 'Сакриј адресе';
$html_outlook_quoting = 'Outlook стил цитирања';
$html_reply_to = 'Одговор на';
$html_use_signature = 'Користи потпис';
$html_signature = 'Потпис';
$html_signature_label = 'Потпис:';
$html_reply_leadin_label = 'Одговори водећи:';
$html_prefs_updated = 'Поставке су ажуриране';
$html_manage_folders_link = 'Управљање IMAP фасциклама';
$html_manage_filters_link = 'Управљање филтерима е-поште';
$html_use_graphical_smilies = 'Користи смешке';
$html_sent_folder_label = 'Умножи послате е-поруке у одређену фасциклу:';
$html_trash_folder_label = 'Премести обрисане е-поруке у одређену фасциклу:';
$html_colored_quotes = 'Обојени цитати';
$html_display_struct = 'Прикажи састављен текст';
$html_send_html_mail = 'Пошаљи е-поруку у HTML формату';
$html_folders = 'Фасцикле';
$html_folders_create_failed = 'Фасцикла није направљена!';
$html_folders_sub_failed = 'Не можете се пријавити на фасциклу!';
$html_folders_unsub_failed = 'Не можете се одјавити из фасцикле!';
$html_folders_rename_failed = 'Фасцикла није преименована!';
$html_folders_updated = 'Фасцикле су ажуриране';
$html_folder_subscribe = 'Пријави ме на';
$html_folder_rename = 'Преименуј';
$html_folder_create = 'Направи нову фасциклу под називом';
$html_folder_remove = 'Одјави ме из';
$html_folder_delete = 'Обриши';
$html_folder_to = 'у';
$html_filter_remove = 'Обриши';
$html_filter_body = 'Текст поруке';
$html_filter_subject = 'Наслов поруке';
$html_filter_to = 'за поље';
$html_filter_cc = 'cc поље';
$html_filter_from = 'од поље';
$html_filter_change_tip = 'Да бисте променили филтер, замените га.';
$html_reapply_filters = 'Поново примени све филтере';
$html_filter_contains = 'садржи';
$html_filter_name = 'Назив филтера';
$html_filter_action = 'Радња филтера';
$html_filter_moveto = 'Премести у';
$html_select_one = 'изаберите';
$html_and = 'и';
$html_new_msg_in = 'Нове поруке у';
$html_or = 'или';
$html_move = 'Премести';
$html_copy = 'Умножи';
$html_messages_to = 'изабране поруке у';
$html_gotopage = 'Пређи на страницу';
$html_gotofolder = 'Пређи на фасциклу';
$html_other_folders = 'Списак фасцикли';
$html_page = 'Страница';
$html_of = 'од';
$html_view_header = 'Прикажи заглавље';
$html_remove_header = 'Сакриј заглавље';
$html_inbox = 'Примљене';
$html_new_msg = 'Састави поруку';
$html_reply = 'Одговори';
$html_reply_short = 'Одг:';
$html_reply_all = 'Одговори свима';
$html_forward = 'Проследи';
$html_forward_short = 'Просл:';
$html_forward_info = 'Прослеђена порука биће послата као прилог ове поруке.';
$html_delete = 'Обриши';
$html_new = 'Ново';
$html_mark = 'Обриши';
$html_att_label = 'Прилог:';
$html_atts_label = 'Прилози:';
$html_unknown = '(непознато)';
$html_part_x = 'Део %s';
$html_attach = 'Приложи';
$html_attach_forget = 'Морате приложити датотеку пре слања поруке!';
$html_attach_delete = 'Уклони изабрано';
$html_attach_none = 'Морате изабрати датотеку прилога!';
$html_sort_by = 'Поређај по';
$html_sort = 'Поређај';
$html_from = 'Од';
$html_from_label = 'Од:';
$html_subject = 'Наслов';
$html_subject_label = 'Наслов:';
$html_date = 'Датум';
$html_date_label = 'Датум:';
$html_sent_label = 'Послато:';
$html_wrote = 'написа';
$html_size = 'Величина';
$html_totalsize = 'Укупна величина';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'бајтова';
$html_filename = 'Назив датотеке';
$html_to = 'За';
$html_to_label = 'За:';
$html_cc = 'CC';
$html_cc_label = 'Cc:';
$html_bcc_label = 'BCC:';
$html_nosubject = 'Без наслова';
$html_send = 'Пошаљи';
$html_cancel = 'Откажи';
$html_no_mail = 'Нема порука.';
$html_logout = 'Одјави ме';
$html_msg = 'Порука';
$html_msgs = 'Поруке';
$html_configuration = 'Овај сервер није исправно подешен!';
$html_priority = 'Приоритет';
$html_priority_label = 'Приоритет:';
$html_lowest = 'Најнижи';
$html_low = 'Низак';
$html_normal = 'Нормалан';
$html_high = 'Висок';
$html_highest = 'Највиши';
$html_flagged = 'Означено';
$html_spam = 'Непожељне поруке';
$html_spam_warning = 'Ова порука је означена као непожељна.';
$html_receipt = 'Затражи повратну потврду';
$html_select = 'Изабери';
$html_select_all = 'Обрни избор';
$html_select_contacts = 'Изабери контакте';
$html_loading_image = 'Учитавање слике';
$html_send_confirmed = 'Ваша е-адреса је прихваћена за доставу';
$html_no_sendaction = 'Нема одређене радње. Пробајте да омогућите јаваскрипту.';
$html_error_occurred = 'Дошло је до грешке';
$html_prefs_file_error = 'Отварање датотеке подешавања за писање није успело.';
$html_wrap = 'Број знакова за умотавање одлазних порука:';
$html_wrap_none = 'Без умотавања';
$html_usenet_separator = 'Раздвајач („-- \n“) пре потписа';
$html_mark_as = 'Означи као';
$html_read = 'прочитано';
$html_unread = 'непрочитано';
$html_encoding_label = 'Кодни распоред:';
$html_add = 'Додај';
$html_contacts = '%1$s контакти';
$html_modify = 'Измени';
$html_back = 'Назад';
$html_contact_add = 'Додај нови контакт';
$html_contact_mod = 'Измени контакт';
$html_contact_first = 'Име';
$html_contact_last = 'Презиме';
$html_contact_nick = 'Надимак';
$html_contact_mail = 'Е-пошта';
$html_contact_list = 'Списак контаката од %1$s';
$html_contact_del = 'из списка контаката';
$html_contact_count = '%1$d контакти';
$html_contact_err1 = 'Највећи број контаката је „%1$d“';
$html_contact_err2 = 'Не можете да додате нови контакт';
$html_contact_err3 = 'Немате овлашћења да приступите списку контаката';
$html_contact_none = 'Контакти нису пронађени.';
$html_del_msg = 'Обрисати изабране поруке?';
$html_down_mail = 'Преузми';
$original_msg = 'оригинална порука';
$to_empty = 'Поље „За“ не може остати празно!';
$html_images_warning = 'Слике нису приказане ради ваше безбедности.';
$html_images_display = 'Прикажи слике';
$html_smtp_error_no_conn = 'Отварање SMTP везе није успело';
$html_smtp_error_unexpected = 'Неочекивани SMTP одговор:';
$lang_could_not_connect = 'Повезивање на сервер није успело';
$lang_invalid_msg_num = 'Неисправан број поруке';
$html_file_upload_attack = 'Могући напад у току отпремања датотеке';
$html_invalid_email_address = 'Неисправна е-адреса';
$html_invalid_msg_per_page = 'Неисправан број порука по страни';
$html_invalid_wrap_msg = 'Неисправна ширина умотавања поруке';
$html_seperate_msg_win = 'Поруке у одвојеним прозорима';
$html_err_file_contacts = 'Отварање датотеке контаката за писање није успело.';
$html_session_file_error = 'Отварање датотеке сесије за писање није успело.';
$html_login_not_allowed = 'Пријава за везу није дозвољена.';
$lang_err_send_delay = 'Морате да сачекате између две е-поруке (%1$d секунди)';
$html_search = 'Претрага';
